@@ -1,9 +1,11 @@
 package Mojolicious::Plugin::BootstrapHelpers {
-    use strict;
+$Mojolicious::Plugin::BootstrapHelpers::VERSION = '0.0161';
+use strict;
+    use warnings;
     use true;
-    
+
     use Mojo::Base 'Mojolicious::Plugin';
-    
+
     use List::AllUtils qw/uniq first_index/;
     use Mojo::ByteStream;
     use Mojo::Util 'xml_escape';
@@ -13,8 +15,6 @@ package Mojolicious::Plugin::BootstrapHelpers {
 
     use experimental 'postderef'; # requires 5.20
 
-    our $VERSION = '0.014';
-
     sub register {
         my $self = shift;
         my $app = shift;
@@ -32,7 +32,8 @@ package Mojolicious::Plugin::BootstrapHelpers {
         $app->helper($tp.'submit_button' => \&Mojolicious::Plugin::BootstrapHelpers::Helpers::bootstrap_submit);
         $app->helper($tp.'badge' => \&Mojolicious::Plugin::BootstrapHelpers::Helpers::bootstrap_badge);
         $app->helper($tp.'dropdown' => \&Mojolicious::Plugin::BootstrapHelpers::Helpers::bootstrap_dropdown);
-        
+        $app->helper($tp.'buttongroup' => \&Mojolicious::Plugin::BootstrapHelpers::Helpers::bootstrap_buttongroup);
+
         if(exists $args->{'icons'}{'class'} && $args->{'icons'}{'formatter'}) {
             $app->config->{'Plugin::BootstrapHelpers'} = $args;
             $app->helper($tp.'icon' => \&Mojolicious::Plugin::BootstrapHelpers::Helpers::bootstrap_icon);
@@ -40,12 +41,13 @@ package Mojolicious::Plugin::BootstrapHelpers {
 
         if($init_short_strappings) {
             my @sizes = qw/xsmall small medium large/;
-            my @contexts = qw/default primary success info warning danger/;
+            my @contexts = qw/default active primary success info warning danger/;
             my @table = qw/striped bordered hover condensed responsive/;
-            my @direction = qw/right/;
-            my @menu = qw/caret divider/;
+            my @direction = qw/right block/;
+            my @menu = qw/caret/;
+            my @misc = qw/disabled/;
 
-            foreach my $helper (@sizes, @contexts, @table, @direction, @menu) {
+            foreach my $helper (@sizes, @contexts, @table, @direction, @menu, @misc) {
                $app->helper($ssp.$helper, sub { ("__$helper" => 1) });
             }
         }
@@ -55,8 +57,7 @@ package Mojolicious::Plugin::BootstrapHelpers {
         my $prefix = shift;
 
         return defined $prefix && !length $prefix   ?   '_'
-             : defined $prefix && $prefix eq '_'    ?   '_'
-             : defined $prefix                      ?   $prefix.'_'
+             : defined $prefix                      ?   $prefix
              :                                          ''
              ;
     }
@@ -70,6 +71,8 @@ __END__
 
 Mojolicious::Plugin::BootstrapHelpers - Type less bootstrap
 
+=for html <p><a style="float: left;" href="https://travis-ci.org/Csson/p5-mojolicious-plugin-bootstraphelpers"><img src="https://travis-ci.org/Csson/p5-mojolicious-plugin-bootstraphelpers.svg?branch=master">&nbsp;</a>
+
 =head1 SYNOPSIS
 
     # Mojolicious
@@ -114,12 +117,12 @@ If you don't know what Bootstrap is, see L<http://www.getbootstrap.com/> for pos
 You might want to use L<Mojolicious::Plugin::Bootstrap3> in your templates.
 
 To get going quickly by using the official CDN you can use the following helpers:
-    
+
     # CSS
     %= bootstrap
 
     <link rel="stylesheet" href="//maxcdn.bootstrapcdn.com/bootstrap/3.2.0/css/bootstrap.min.css">
-    
+
     # or (if you want to use the theme)
     %= bootstrap 'theme'
 
@@ -139,14 +142,14 @@ To get going quickly by using the official CDN you can use the following helpers
     <script src="//maxcdn.bootstrapcdn.com/bootstrap/3.2.0/js/bootstrap.min.js"></script>
 
 It is also possible to automatically include jQuery (2.*)
-    
+
     %= bootstrap 'jsq'
-    
+
     <script src="//code.jquery.com/jquery-2.1.1.min.js"></script>
     <script src="//maxcdn.bootstrapcdn.com/bootstrap/3.2.0/js/bootstrap.min.js"></script>
 
     %= bootstrap 'allq'
-    
+
     <link rel="stylesheet" href="//maxcdn.bootstrapcdn.com/bootstrap/3.2.0/css/bootstrap.min.css">
     <link rel="stylesheet" href="//maxcdn.bootstrapcdn.com/bootstrap/3.2.0/css/bootstrap-theme.min.css">
     <script src="//code.jquery.com/jquery-2.1.1.min.js"></script>
@@ -155,7 +158,7 @@ It is also possible to automatically include jQuery (2.*)
 
 =head2 Strappings
 
-There are several shortcuts ("strappings") for applying context and size classes that automatically expands to the correct class depending 
+There are several shortcuts ("strappings") for applying context and size classes that automatically expands to the correct class depending
 on which tag it is applied to. For instance, if you apply the C<info> strapping to a panel, it becomes C<panel-info>, but when applied to a button it becomes C<btn-info>.
 
 You can use them in two different ways, but internally they are the same. These to lines are exactly identical:
@@ -172,7 +175,7 @@ They are shortened to the Bootstrap type classes.
 The following strappings are available:
 
    xsmall    default     striped       caret     right
-   small     primary     bordered      divider
+   small     primary     bordered
    medium    success     hover
    large     info        condensed
              warning     responsive
@@ -186,7 +189,7 @@ If there is no corresponding class for the element you add the strapping to it i
 
 =begin html
 
-<p>The short form is recommended for readability, but it does setup several helpers in your templates. 
+<p>The short form is recommended for readability, but it does setup several helpers in your templates.
 You can turn off the short forms, see <a href="#init_short_strappings">init_short_strappings</a>.</p>
 
 =end html
@@ -194,7 +197,7 @@ You can turn off the short forms, see <a href="#init_short_strappings">init_shor
 =head2 Syntax convention
 
 In the syntax sections below the following conventions are used:
-    
+
     name            A specific string
     $name           Any string
     %name           One or more key-value pairs, written as:
@@ -226,9 +229,9 @@ The following applies to all C<%has> hashes below:
 
 =item * Depending on context either the leading or following comma is optional together with the hash. It is usually obvious.
 
-=item * Sometimes on nested helpers (such as tables in panels just below), C<%has> is the only thing that can be applied to 
+=item * Sometimes on nested helpers (such as tables in panels just below), C<%has> is the only thing that can be applied to
         the other element. In this case C<panel =E<gt> { %panel_has }>. It follows from above that in those cases this entire
-        expression is I<also> optional. Such cases are also not marked as optional in syntax definitions and are not mentioned 
+        expression is I<also> optional. Such cases are also not marked as optional in syntax definitions and are not mentioned
         in syntax description, unless they need further comment.
 
 =back
@@ -240,98 +243,275 @@ From this definition:
     %  end
 
 Both of these are legal:
-    
+
     # since both panel => { %panel_has } and %table_has are hashes, their ordering is not significant.
     %= table 'Heading Table', panel => { success }, condensed, id => 'the-table', begin
          <tr><td>A Table Cell</td></tr>
     %  end
-    
+
 
     %= table begin
          <tr><td>A Table Cell</td></tr>
     %  end
-        
 
 
 =head1 HELPERS
 
-=head2 Panels
+L<Bootstrap documentation|http://getbootstrap.com/components/#badges>
 
-L<Bootstrap documentation|http://getbootstrap.com/components/#panels>
+=head2 Badges
 
 =head3 Syntax
 
-    %= panel ($title, %has, begin
-        $body
-    %  end)
+    %= badge $text, %has
 
-B<C<$title>>
+B<C<$text>>
 
-Usually mandatory, but can be omitted if there are no other arguments to the C<panel>. Otherwise, if you don't want a title, set it C<undef>.
+Mandatory. If it is C<undef> no output is produced.
 
-B<C<$body>>
 
-Optional (but panels are not much use without it). The html inside the C<panel>.
+B<Available strappings>
+
+C<right> applies C<.pull-right>.
 
 
 =head3 Examples
 
-B<No body, no title>
 
-    %= panel
+    <%= badge '3' %>
 
-    <div class="panel panel-default">
-        <div class="panel-body">
-        </div>
+    <span class="badge">3</span></a>
+
+=begin html
+
+<p>
+A basic badge.
+
+</p>
+
+=end html
+
+
+    <%= badge '4', data => { custom => 'yes' }, right %>
+
+    <span class="badge pull-right" data-custom="yes">4</span>
+
+=begin html
+
+<p>
+A right aligned badge with a data attribute.
+
+</p>
+
+=end html
+
+
+
+
+=head2 Buttons
+
+L<Bootstrap documentation|http://getbootstrap.com/css/#buttons>
+
+=head3 Syntax
+
+    %= button $button_text(, [$url]), %has
+
+    %= submit_button $text, %has
+
+B<C<$button_text>>
+
+Mandatory. The text on the button.
+
+B<C<[$url]>>
+
+Optional array reference. It is handed off to L<url_for|Mojolicious::Controller#url_for>, so with it this is
+basically L<link_to|Mojolicious::Plugin::TagHelpers#link_to> with Bootstrap classes.
+
+Not available for C<submit_button>.
+
+
+B<Available strappings>
+
+C<default> C<primary> C<success> C<info> C<warning> C<danger> C<link> applies the various C<.btn-*> classes.
+
+C<large> C<small> C<xsmall> applies C<.btn-lg> C<.btn-sm> C<.btn-xs> respectively.
+
+C<active> C<block> applies the C<.active> and C<.block> classes.
+
+C<disabled> applies the C<.disabled> class if the generated element is an C<E<lt>aE<gt>>. On a C<E<lt>buttonE<gt>> it applies the C<disabled="disabled"> attribute.
+
+
+=head3 Examples
+
+
+    %= button 'The example 5' => large, warning
+
+    <button class="btn btn-lg btn-warning">The example 5</button>
+
+=begin html
+
+<p>
+An ordinary button, with applied strappings.
+
+</p>
+
+=end html
+
+
+    %= button 'The example 1' => ['http://www.example.com/'], small
+
+    <a class="btn btn-default btn-sm" href="http://www.example.com/">The example 1</a>
+
+=begin html
+
+<p>
+With a url the button turns into a link.
+
+</p>
+
+=end html
+
+
+    %= submit_button 'Save 2', primary
+
+    <button class="btn btn-primary" type="submit">Save 2</button>
+
+=begin html
+
+<p>
+A submit button for use in forms. It overrides the build-in submit_button helper.
+
+</p>
+
+=end html
+
+
+
+
+=head2 Dropdowns
+
+=head3 Syntax
+
+    <%= dropdown  %has,
+                  button => [ $button_text, %button_has ],
+                  items  => [
+                      [ $itemtext, [ $url ], %item_has ],
+                     ($headertext,)
+                     ([],)
+                  ]
+
+Nesting is currently not supported.
+
+B<C<button =E<gt> []>>
+
+Mandatory array reference. Takes the same arguments as an ordinary L<button|/"Buttons">, with two exceptions: It can't take a url, and it can take the C<caret> strapping.
+
+B<C<items>>
+
+Mandatory array reference. Here are the items that make up the menu. It takes two different types of value (both can occur any number of times:
+
+=over 4
+
+B<C<[ $itemtext, [ $url ], %item_has ]>>
+
+This creates a linked menu item.
+
+=over 4
+
+B<C<$itemtext>>
+
+Mandatory. The text on the link.
+
+B<C<$url>>
+
+Mandatory. It sets the C<href> on the link. L<url_for|Mojolicious::Controller#url_for> is used to create the link.
+
+=back
+
+B<C<$headertext>>
+
+A string creates a dropdown header.
+
+B<C<[]>>
+
+An empty array reference creates a divider.
+
+=back
+
+
+B<Available strappings>
+
+C<caret> adds a C<E<lt>span class="caret"E<gt>E<lt>/span<E<gt>> element on the button.
+
+
+=head3 Examples
+
+
+    <%= dropdown
+         button => ['Dropdown 1', id => 'a_custom_id'],
+         right,
+         items => [
+            ['Item 1', ['item1'] ],
+            ['Item 2', ['item2'] ],
+            [],
+            ['Item 3', ['item3'] ]
+         ] %>
+
+    <div class="dropdown">
+        <button class="btn btn-default dropdown-toggle" type="button" id="a_custom_id" data-toggle="dropdown">Dropdown 1</button>
+        <ul class="dropdown-menu dropdown-menu-right">
+            <li><a class="menuitem" href="item1" tabindex="-1">Item 1</a></li>
+            <li><a class="menuitem" href="item2" tabindex="-1">Item 2</a></li>
+            <li class="divider"></li>
+            <li><a class="menuitem" href="item3" tabindex="-1">Item 3</a></li>
+        </ul>
     </div>
 
-The class is set to C<panel-default>, by default.
+=begin html
 
-B<Body, no title>
+<p>
+By default, <code>tabindex</code> is set to <code>-1</code>...
 
-    %= panel undef ,=> begin
-        <p>A short text.</p>
-    %  end
+</p>
 
-    <div class="panel panel-default">
-        <div class="panel-body">
-            <p>A short text.</p>
-        </div>
+=end html
+
+
+    <%= dropdown
+         button => ['Dropdown 2', caret, large, primary],
+         items => [
+            ['Item 1', ['item1'], data => { attr => 2 } ],
+            ['Item 2', ['item2'], disabled, data => { attr => 4 } ],
+            [],
+            ['Item 3', ['item3'], data => { attr => 7 } ],
+            [],
+            ['Item 4', ['item4'], tabindex => 4 ],
+            'This is a header',
+            ['Item 5', ['item5'] ],
+         ] %>
+
+    <div class="dropdown">
+        <button class="btn btn-lg btn-primary dropdown-toggle" type="button" data-toggle="dropdown">Dropdown 2 <span class="caret"></span></button>
+        <ul class="dropdown-menu">
+            <li><a class="menuitem" href="item1" tabindex="-1" data-attr="2">Item 1</a></li>
+            <li class="disabled"><a class="menuitem" href="item2" tabindex="-1" data-attr="4">Item 2</a></li>
+            <li class="divider"></li>
+            <li><a class="menuitem" href="item3" tabindex="-1" data-attr="7">Item 3</a></li>
+            <li class="divider"></li>
+            <li><a class="menuitem" href="item4" tabindex="4">Item 4</a></li>
+            <li class="dropdown-header">This is a header</li>
+            <li><a class="menuitem" href="item5" tabindex="-1">Item 5</a></li>
+        </ul>
     </div>
 
-If you want a panel without title, set the title to C<undef>. Note that you can't use a regular fat comma since that would turn undef into a string. A normal comma is of course also ok.
+=begin html
 
-B<Body and title>
+<p>
+...but it can be overridden.
+</p>
 
-    %= panel 'The header' => begin
-        <p>A short text.</p>
-    %  end
+=end html
 
-    <div class="panel panel-default">
-        <div class="panel-heading">
-            <h3 class="panel-title">The Header</h3>
-        </div>
-        <div class="panel-body">
-            <p>A short text.</p>
-        </div>
-    </div>
-
-B<Body and title, with context>
-    
-    %= panel 'Panel 5', success, begin
-        <p>A short text.</p>
-    %  end
-    
-    <div class="panel panel-success">
-        <div class="panel-heading">
-            <h3 class="panel-title">Panel 5</h3>
-        </div>
-        <div class="panel-body">
-            <p>A short text.</p>
-        </div>
-    </div>
-
-Here, the C<success> strapping applies C<.panel-success> to the panel.
 
 
 
@@ -340,7 +520,7 @@ Here, the C<success> strapping applies C<.panel-success> to the panel.
 L<Bootstrap documentation|http://getbootstrap.com/css/#forms>
 
 =head3 Syntax
-    
+
     <%= formgroup ($labeltext,)
                    %formgroup_has,
                   (cols => { $size => [ $label_columns, $input_columns ], (...) })
@@ -351,7 +531,7 @@ L<Bootstrap documentation|http://getbootstrap.com/css/#forms>
                   ]
 
     %>
-    
+
     # The $labeltext can also be given in the body
     %= formgroup <as above>, begin
         $labeltext
@@ -387,7 +567,7 @@ Mandatory. The number of columns that should be used by the input for that size
 
 B<C<$fieldtype>>
 
-Mandatory. Is one of C<text_field>, C<password_field>, C<datetime_field>, C<date_field>, C<month_field>, C<time_field>, C<week_field>, 
+Mandatory. Is one of C<text_field>, C<password_field>, C<datetime_field>, C<date_field>, C<month_field>, C<time_field>, C<week_field>,
 C<number_field>, C<email_field>, C<url_field>, C<search_field>, C<tel_field>, C<color_field>.
 
 There can be only one C<$fieldtype> per C<formgroup>.
@@ -408,198 +588,24 @@ Optional. If you prefer you can set C<value> in C<%input_has> instead. (But don'
 
 =head3 Examples
 
-B<Basic form group>
-    
-    %= formgroup 'Text test 1', text_field => ['test_text']
 
-    <div class="form-group">
-        <label class="control-label" for="test_text">Text test 1</label>
-        <input class="form-control" id="test_text" name="test_text" type="text" />
-    </div>
-
-The first item in the array ref is used for both C<id> and C<name>. Except...
-
-
-    %= formgroup 'Text test 4', text_field => ['test_text', large]
+    %= formgroup 'Text test 4', text_field => ['test-text', large]
 
     <div class="form-group">
         <label class="control-label" for="test-text">Text test 4</label>
-        <div class="input-group">
-            <input class="form-control input-lg" id="test-text" name="test_text" type="text" />
-            <span class="input-group-addon">.00</span>
-        </div>
+        <input class="form-control input-lg" id="test-text" name="test_text" type="text" />
     </div>
 
-...if the input name (the first item in the text_field array ref) contains dashes -- those are replaced (in the C<name>) to underscores.
-
-Strappings can also be used in this context. Here C<large> applies C<.input-lg>.
-
-
-    %= formgroup 'Text test 5', text_field => ['test_text', '200' ]
-
-    <div class="form-group">
-        <label class="control-label" for="test_text">Text test 5</label>
-        <input class="form-control" id="test_text" name="test_text" type="text" value="200" />
-    </div>
-
-Here, the second item in the C<text_field> array reference is a value that populates the C<input>.
-
 =begin html
 
-<p><hr></p>
+<p>
+...if the input name (the first item in the text_field array ref) contains dashes -- those are replaced (in the <code>name</code>) to underscores.
 
-=end html 
+</p>
 
-    %= formgroup 'Text test 6', text_field => ['test_text'], large
-
-    <div class="form-group form-group-lg">
-        <label class="control-label" for="test_text">Text test 6</label>
-        <input class="form-control" id="test_text" name="test_text" type="text" />
-    </div>
-
-Note the difference with the earlier example. Here C<large> is outside the C<text_field> array reference, and therefore C<.form-group-lg> is applied to the form group. 
+=end html
 
 
-    %= formgroup 'Text test 8', text_field => ['test_text'], cols => { medium => [2, 10], small => [4, 8] }
-
-    <div class="form-group">
-        <label class="control-label col-md-2 col-sm-4" for="test_text">Text test 8</label>
-        <div class="col-md-10 col-sm-8">
-            <input class="form-control" id="test_text" name="test_text" type="text" />
-        </div>
-    </div>
-
-If the C<form> is C<.form-horizontal>, you can set the column widths with the C<cols> attribute. The first item in each array ref is for the label, and the second for the input.
-
-(Note that in this context, C<medium> and C<large> are not short form strappings. Those don't take arguments.)
-
-
-
-=head2 Buttons
-
-L<Bootstrap documentation|http://getbootstrap.com/css/#buttons>
-
-=head3 Syntax
-
-    %= button $button_text(, [$url]), %has
-
-    %= submit_button $text, %has
-
-B<C<$button_text>>
-
-Mandatory. The text on the button.
-
-B<C<[$url]>>
-
-Optional array reference. It is handed off to L<url_for|Mojolicious::Controller#url_for>, so with it this is
-basically L<link_to|Mojolicious::Plugin::TagHelpers#link_to> with Bootstrap classes.
-
-Not available for C<submit_button>.
-
-=head3 Examples
-
-    %= button 'The example 5' => large, warning
-
-    <button class="btn btn-lg btn-warning">The example 5</button>
-
-An ordinary button, with applied strappings.
-    
-    %= button 'The example 1' => ['http://www.example.com/'], small
-
-    <a class="btn btn-sm" href="http://www.example.com/">The example 1</a>
-
-With a url the button turns into a link.
-
-    %= submit_button 'Save', __primary
-
-    <button class="btn btn-primary" type="submit">Save 2</button>
-
-A submit button for use in forms. It overrides the build-in submit_button helper.
-
-=head2 Tables
-
-=head3 Syntax
-    
-    %= table ($title,) %table_has, panel => { %panel_has }, begin
-           $body
-    %  end
-    
-B<C<$title>>
-
-Optional. If set the table will be wrapped in a panel, and the table replaces the body in the panel.
-
-B<C<$body>>
-
-Mandatory. C<thead>, C<td> and so on.
-
-B<C<panel =E<gt> { %panel_has }>>
-
-Optional if the table has a C<$title>, otherwise without use.
-
-
-=head3 Examples
-
-L<Bootstrap documentation|http://getbootstrap.com/css/#tables>
-
-    <%= table begin %>
-        <tr><td>Table 1</td></tr>
-    <% end %>
-
-    <table class="table">
-        <tr><td>Table 1</td></tr>
-    </table>
-
-A basic table.
-
-    %= table hover, striped, condensed, begin
-        <tr><td>Table 2</td></tr>
-    %  end
-
-    <table class="table table-condensed table-hover table-striped">
-        <tr><td>Table 2</td></tr>
-    </table>
-
-Several classes applied to the table.
-
-    %= table 'Heading Table 4', panel => { success }, condensed, id => 'the-table', begin
-        <tr><td>Table 4</td></tr>
-    %  end
-
-    <div class="panel panel-success">
-        <div class="panel-heading">
-            <h3 class="panel-title">Heading Table 4</h3>
-        </div>
-        <table class="table table-condensed" id="the-table">
-            <tr><td>Table 4</td></tr>
-        </table>
-    </div>
-
-A C<condensed> table with an C<id> wrapped in a C<success> panel.
-
-
-=head2 Badges
-
-=head3 Syntax
-
-    %= badge $text, %has
-
-B<C<$text>>
-
-Mandatory. If it is C<undef> no output is produced.
-
-=head3 Examples
-
-    <%= badge '3' %>
-
-    <span class="badge">3</span></a>
-    
-A basic badge.
-
-    <%= badge '4', data => { custom => 'yes' }, right %>
-    
-    <span class="badge pull-right" data-custom="yes">4</span>
-
-A right aligned badge with a data attribute.
 
 
 =head2 Icons
@@ -615,7 +621,8 @@ B<C<$icon_name>>
 Mandatory. The specific icon you wish to create. Possible values depends on your icon pack.
 
 =head3 Examples
-    
+
+
     <%= icon 'copyright-mark' %>
     %= icon 'sort-by-attributes-alt'
 
@@ -623,106 +630,194 @@ Mandatory. The specific icon you wish to create. Possible values depends on your
     <span class="glyphicon glyphicon-sort-by-attributes-alt"></span>
 
 
-=head2 Dropdowns
+
+
+=head2 Panels
+
+L<Bootstrap documentation|http://getbootstrap.com/components/#panels>
 
 =head3 Syntax
-    
-    <%= dropdown  $button_text,
-                 (caret,)
-                  %has,
-                 (button => [ %button_has ],)
-                  items  => [ 
-                      [ $itemtext, [ $url ], %item_has ],
-                     (divider,)
-                  ]
 
-Nesting is currently not supported.
+    %= panel ($title, %has, begin
+        $body
+    %  end)
 
-B<C<$button_text>>
+B<C<$title>>
 
-Mandatory. The text that appears on the menu opening button.
+Usually mandatory, but can be omitted if there are no other arguments to the C<panel>. Otherwise, if you don't want a title, set it C<undef>.
 
-B<C<caret>>
+B<C<$body>>
 
-It is a strapping. If it is used a caret (downward facing arrow) will be placed on the button.
+Optional (but panels are not much use without it). The html inside the C<panel>.
 
-B<C<items>>
-
-Mandatory array reference. Here are the items that make up the menu. It takes two different types of value (both can occur any number of times:
-
-=over 4
-
-B<C<divider>>
-
-Creates a horizontal separator in the menu.
-
-B<C<[ $itemtext, [ $url ], %item_has ]>>
-
-This creates a linked menu item.
-
-=over 4
-
-B<C<$itemtext>>
-
-Mandatory. The text on the link.
-
-B<C<$url>>
-
-Mandatory. It sets the C<href> on the link. L<url_for|Mojolicious::Controller#url_for> is used to create the link.
-
-=back
-
-=back
 
 =head3 Examples
 
-    <%= dropdown 'Dropdown 1',
-                 button => [id => 'a_custom_id'],
-                 items => [
-                    ['Item 1', ['item1'] ],
-                    ['Item 2', ['item2'] ],
-                    divider,
-                    ['Item 3', ['item3'] ]
-                 ] %>
 
-    <div class="dropdown">
-        <button class="btn btn-default dropdown-toggle" type="button" id="a_custom_id" data-toggle="dropdown">Dropdown 1</button>
-        <ul class="dropdown-menu">
-            <li><a class="menuitem" href="item1" tabindex="-1">Item 1</a></li>
-            <li><a class="menuitem" href="item2" tabindex="-1">Item 2</a></li>
-            <li class="divider"></li>
-            <li><a class="menuitem" href="item3" tabindex="-1">Item 3</a></li>
-        </ul>
+    %= panel
+
+    <div class="panel panel-default">
+        <div class="panel-body">
+        </div>
     </div>
 
-By default, C<tabindex> is set to C<-1>...
+=begin html
 
-    <%= dropdown 'Dropdown 2', caret,
-                 items => [
-                    ['Item 1', ['item1'], data => { attr => 2 } ],
-                    ['Item 2', ['item2'], data => { attr => 4 } ],
-                    divider,
-                    ['Item 3', ['item3'], data => { attr => 7 } ],
-                    divider,
-                    ['Item 4', ['item4'], tabindex => 4 ],
-                 ] %>
+<p>
+The class is set to <code>.panel-default</code>, by default.
 
-    <div class="dropdown">
-        <button class="btn btn-default dropdown-toggle" type="button" data-toggle="dropdown">
-            Dropdown 2
-            <span class="caret"></span>
-        </button>
-        <ul class="dropdown-menu">
-            <li><a class="menuitem" href="item1" tabindex="-1" data-attr="2">Item 1</a></li>
-            <li><a class="menuitem" href="item2" tabindex="-1" data-attr="4">Item 2</a></li>
-            <li class="divider"></li>
-            <li><a class="menuitem" href="item3" tabindex="-1" data-attr="7">Item 3</a></li>
-            <li class="divider"></li>
-            <li><a class="menuitem" href="item4" tabindex="4">Item 4</a></li>
-        </ul>
+</p>
+
+=end html
+
+
+    %= panel undef ,=> begin
+        <p>A short text.</p>
+    %  end
+
+    <div class="panel panel-default">
+        <div class="panel-body">
+            <p>A short text.</p>
+        </div>
     </div>
 
-...but it can be overridden.
+=begin html
+
+<p>
+If you want a panel without title, set the title to <code>undef</code>.
+
+</p>
+
+=end html
+
+
+    %= panel 'The Header' => begin
+        <p>A short text.</p>
+    %  end
+
+    <div class="panel panel-default">
+        <div class="panel-heading">
+            <h3 class="panel-title">The Header</h3>
+        </div>
+        <div class="panel-body">
+            <p>A short text.</p>
+        </div>
+    </div>
+
+
+    %= panel 'Panel 5', success, begin
+        <p>A short text.</p>
+    %  end
+
+    <div class="panel panel-success">
+        <div class="panel-heading">
+            <h3 class="panel-title">Panel 5</h3>
+        </div>
+        <div class="panel-body">
+            <p>A short text.</p>
+        </div>
+    </div>
+
+
+
+
+
+=head2 Tables
+
+L<Bootstrap documentation|http://getbootstrap.com/css/#tables>
+
+=head3 Syntax
+
+    %= table ($title,) %table_has, panel => { %panel_has }, begin
+           $body
+    %  end
+
+B<C<$title>>
+
+Optional. If set the table will be wrapped in a panel, and the table replaces the body in the panel.
+
+B<C<$body>>
+
+Mandatory. C<thead>, C<td> and so on.
+
+B<C<panel =E<gt> { %panel_has }>>
+
+Optional if the table has a C<$title>, otherwise without use.
+
+
+=head3 Examples
+
+
+
+=begin html
+
+<p>
+
+</p>
+
+=end html
+
+    <%= table begin %>
+        <tr><td>Table 1</td></tr>
+    <% end %>
+
+    <table class="table">
+        <tr><td>Table 1</td></tr>
+    </table>
+
+=begin html
+
+<p>
+A basic table.
+
+</p>
+
+=end html
+
+
+    %= table hover, striped, condensed, begin
+        <tr><td>Table 2</td></tr>
+    %  end
+
+    <table class="table table-condensed table-hover table-striped">
+        <tr><td>Table 2</td></tr>
+    </table>
+
+=begin html
+
+<p>
+Several classes applied to the table.
+
+</p>
+
+=end html
+
+
+    %= table 'Heading Table 4', panel => { success }, condensed, id => 'the-table', begin
+        <tr><td>Table 4</td></tr>
+    %  end
+
+    <div class="panel panel-success">
+        <div class="panel-heading">
+            <h3 class="panel-title">Heading Table 4</h3>
+        </div>
+        <table class="table table-condensed" id="the-table">
+            <tr><td>Table 4</td></tr>
+        </table>
+    </div>
+
+=begin html
+
+<p>
+A <code>condensed</code> table with an <code>id</code> wrapped in a <code>success</code> panel.
+
+</p>
+
+=end html
+
+
+
+
 
 =head1 OPTIONS
 
@@ -742,7 +837,7 @@ Some options are available:
 
 Default: C<undef>
 
-If you want to you change the name of the tag helpers, by applying a prefix. These are not aliases; 
+If you want to you change the name of the tag helpers, by applying a prefix. These are not aliases;
 by setting a prefix the original names are no longer available. The following rules are used:
 
 =over 4
@@ -754,11 +849,10 @@ If the option is missing, or is C<undef>, there is no prefix.
 If the option is set to the empty string, the prefix is C<_>. That is, C<panel> is now used as C<_panel>.
 
 =item *
-If the option is set to any other string, the prefix is that string followed by C<_>. If you set C<tag_prefix =E<gt> 'bs'>, then C<panel> is now used as C<bs_panel>.
+If the option is set to any other string, the prefix is that string. If you set C<tag_prefix =E<gt> 'bs'>, then C<panel> is now used as C<bspanel>.
 
 =back
 
-
 =head2 short_strappings_prefix
 
 Default: C<undef>
@@ -812,4 +906,3 @@ This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
 
 =cut
- 
\ No newline at end of file
