@@ -1,21 +1,17 @@
 package Mojolicious::Plugin::BootstrapHelpers::Helpers {
-    use strict;
-    
+$Mojolicious::Plugin::BootstrapHelpers::Helpers::VERSION = '0.0161';
+use strict;
+    use warnings;
     use Mojo::Base 'Mojolicious::Plugin';
-    
+
     use List::AllUtils qw/uniq first_index/;
     use Mojo::ByteStream;
     use Mojo::Util 'xml_escape';
     use Scalar::Util 'blessed';
     use String::Trim;
-    use String::Random;
     use Data::Dumper 'Dumper';
     use experimental 'postderef'; # requires 5.20
 
-    our $VERSION = '0.014';
-
-
-
     sub bootstraps_bootstraps {
         my $c = shift;
         my $arg = shift;
@@ -38,9 +34,9 @@ package Mojolicious::Plugin::BootstrapHelpers::Helpers {
 
     sub bootstrap_panel {
         my($c, $title, $callback, $content, $attr) = parse_call(@_);
-        
+
         $attr = add_classes($attr, 'panel', { panel => 'panel-%s', panel_default => 'default'});
-        
+
         my $body = qq{
                 <div class="panel-body">
                     } . contents($callback, $content) . qq{
@@ -55,7 +51,7 @@ package Mojolicious::Plugin::BootstrapHelpers::Helpers {
         my $title = shift;
         my $body = shift;
         my $attr = shift;
-        
+
         my $tag = qq{
             <div class="$attr->{'class'}">
             } . (defined $title ? qq{
@@ -75,7 +71,7 @@ package Mojolicious::Plugin::BootstrapHelpers::Helpers {
         my $callback = ref $_[-1] eq 'CODE' ? pop : undef;
         my $title = scalar @_ % 2 ? shift : undef;
         my $attr = parse_attributes(@_);
-        
+
         $attr = add_classes($attr, 'table', { table => 'table-%s' });
         my $html = htmlify_attrs($attr);
 
@@ -105,11 +101,11 @@ package Mojolicious::Plugin::BootstrapHelpers::Helpers {
 
     sub bootstrap_formgroup {
         my $c = shift;
-        my $title = ref $_[-1] eq 'CODE' ? pop 
+        my $title = ref $_[-1] eq 'CODE' ? pop
                   : scalar @_ % 2        ? shift
                   :                        undef;
         my $attr = parse_attributes(@_);
-        
+
         $attr->{'column_information'} = delete $attr->{'cols'} if ref $attr->{'cols'} eq 'HASH';
 
         my($id, $input) = fix_input($c, $attr);
@@ -135,25 +131,25 @@ package Mojolicious::Plugin::BootstrapHelpers::Helpers {
 
         my @url = shift->@* if ref $_[0] eq 'ARRAY';
         my $attr = parse_attributes(@_);
-        
-        my $caret = exists $attr->{'__caret'} && $attr->{'__caret'} ? q{<span class="caret"></span>} : '';
+
+        my $caret = exists $attr->{'__caret'} && $attr->{'__caret'} ? q{ <span class="caret"></span>} : '';
 
         $attr = add_classes($attr, 'btn', { size => 'btn-%s', button => 'btn-%s', button_default => 'default' });
+        $attr = add_classes($attr, 'active') if $attr->{'__active'};
+        $attr = add_classes($attr, 'block') if $attr->{'__block'};
+        $attr = add_disabled($attr, scalar @url);
         $attr = cleanup_attrs($attr);
 
-
-
         # We have an url
         if(scalar @url) {
             $attr->{'href'} = $c->url_for(@url)->to_string;
+
             my $html = htmlify_attrs($attr);
             return out(qq{<a$html>} . content_single($content) . qq{$caret</a>});
-#            return out(Mojolicious::Plugin::TagHelpers::_tag('a', $attr->%*, $content));
         }
         else {
             my $html = htmlify_attrs($attr);
             return out(qq{<button$html>} . content_single($content) . qq{$caret</button>});
-            #return out(Mojolicious::Plugin::TagHelpers::_tag('button', $attr->%*, $content));
         }
 
     }
@@ -165,29 +161,46 @@ package Mojolicious::Plugin::BootstrapHelpers::Helpers {
 
     sub bootstrap_dropdown {
         my $c = shift;
-        my $button_text = iscoderef($_[-1]) ? pop : shift;
+
         my $attr = parse_attributes(@_);
         my $button_info = delete $attr->{'button'};
-        my $button_attr = ref $button_info eq 'ARRAY' ? { $button_info->@* } : {};
+
+        my $button_text = shift $button_info->@*;
+        my $button_attr =  { $button_info->@* };
+
         my $items_info = delete $attr->{'items'};
 
-        $button_attr = add_classes($button_attr, 'dropdown-toggle');
-        $button_attr->{'data'}{'toggle'} = 'dropdown';
-        $button_attr->{'type'} = 'button';
-        #$button_attr->{'id'} ||= String::Random->new->randregex('[a-z]\w{19}'); # when aria
+        my $ulattr = { __right => exists $attr->{'__right'} ? delete $attr->{'__right'} : 0 };
+        $ulattr = add_classes($ulattr, 'dropdown-menu');
+        $ulattr = add_classes($ulattr, 'dropdown-menu-right') if $ulattr->{'__right'};
+        my $ulhtml = htmlify_attrs($ulattr);
 
-        my $button = bootstrap_button($c, $button_text, $button_attr->%*, __caret => $attr->{'__caret'});
+        $button_attr = add_classes($button_attr, 'dropdown-toggle');
+        $button_attr->{'data-toggle'} = 'dropdown';
+        $button_attr->{'type'} = 'button';
+        my $button = bootstrap_button($c, $button_text, $button_attr->%*);
 
         my $menuitems = '';
+
+        ITEM:
         foreach my $item ($items_info->@*) {
-            $menuitems .= q{<li class="divider"></li>} if $item eq '__divider';
-            $menuitems .= create_dropdown_menuitem($c, $item->@*) if ref $item eq 'ARRAY';
+            if(ref $item eq '') {
+                $menuitems .= qq{<li class="dropdown-header">$item</li>};
+            }
+            next ITEM if ref $item ne 'ARRAY';
+            if(!scalar $item->@*) {
+                $menuitems .= q{<li class="divider"></li>} ;
+            }
+            else {
+                $menuitems .= create_dropdown_menuitem($c, $item->@*);
+            }
+
         }
 
         my $dropdown = qq{
             <div class="dropdown">
                 $button
-                <ul class="dropdown-menu">
+                <ul$ulhtml>
                     $menuitems
                 </ul>
             </div>
@@ -197,34 +210,62 @@ package Mojolicious::Plugin::BootstrapHelpers::Helpers {
 
     }
 
-    sub create_dropdown_menuitem {use Data::Dumper 'Dumper';
+    sub create_dropdown_menuitem {
         my $c = shift;
         my $item_text = iscoderef($_[-1]) ? pop : shift;
-        
-        
         my @url = shift->@*;
-        
+
         my $attr = parse_attributes(@_);
-        
         $attr = add_classes($attr, 'menuitem');
+        my $liattr = { __disabled => exists $attr->{'__disabled'} ? delete $attr->{'__disabled'} : 0 };
+        $liattr = add_disabled($liattr, 1);
         $attr->{'tabindex'} ||= -1;
         $attr->{'href'} = $c->url_for(@url)->to_string;
-        
-        my $html = htmlify_attrs($attr);
-        
 
-        my $tag = qq{<li><a$html>$item_text</a></li>};
+        my $html = htmlify_attrs($attr);
+        my $lihtml = htmlify_attrs($liattr);
+
+        my $tag = qq{<li$lihtml><a$html>$item_text</a></li>};
 
         return out($tag);
     }
 
-    # %= dropdown 'Dropdown', button => [key => 'value'], 
-    #                         items => [
-    #                             item => ['Action', ['url'], %has], 
-    #                             divider,
-    #                             item => []
-    #                         ],
-    #                         caret
+    sub bootstrap_buttongroup {
+        my $c = shift;
+        my $attr = parse_attributes(@_);
+        my $buttons_info = delete $attr->{'buttons'};
+        my $buttongroups_info = delete $attr->{'buttongroups'};
+        $attr = add_classes($attr, 'btn-group', { size => 'btn-group-%s' });
+        my $html = htmlify_attrs($attr);
+
+        my $buttons = '';
+        foreach my $button ($buttons_info->@*) {
+            $buttons .= bootstrap_button($c, $button->@*, type => 'button');
+        }
+        my $buttongroups = '';
+        foreach my $buttongroup ($buttongroups_info->@*) {
+            $buttongroups .= bootstrap_buttongroup($c, $buttongroup->@*);
+        }
+
+        my $tag = '';
+
+        # Nested groups
+        if(scalar $buttongroups_info->@*) {
+            $tag = qq{
+                <div$html>
+                    $buttongroups
+                </div>
+            };
+        }
+        else {
+            $tag = qq{
+                <div$html>
+                    $buttons
+                </div>
+            };
+        }
+        return out($tag);
+    }
 
     sub bootstrap_badge {
         my $c = shift;
@@ -262,11 +303,11 @@ package Mojolicious::Plugin::BootstrapHelpers::Helpers {
     sub fix_input {
         my $c = shift;
         my $attr = shift;
-        
+
         my $tagname = (grep { exists $attr->{"${_}_field"} } qw/date datetime month time week color email number range search tel text url password/)[0];
         my $info = $attr->{"${tagname}_field"};
         my $id = shift $info->@*;
-        
+
         # if odd number of elements, the first one is the value (shortcut to avoid having to: value => 'value')
         if($info->@* % 2) {
             push $info->@* => (value => shift $info->@*);
@@ -377,11 +418,11 @@ package Mojolicious::Plugin::BootstrapHelpers::Helpers {
                 push @classes => sprintfify_class($attr, $formatter->{'direction'}, $formatter->{'direction_default'}, _direction_contexts());
             }
         }
-       
+
         $attr->{'class'} = trim join ' ' => uniq sort @classes;
 
         return $attr;
-        
+
     }
 
     sub sprintfify_class {
@@ -399,6 +440,21 @@ package Mojolicious::Plugin::BootstrapHelpers::Helpers {
 
     }
 
+    sub add_disabled {
+        my $attr = shift;
+        my $add_as_class = shift; # if false, add as attribute
+
+        if(exists $attr->{'__disabled'} && $attr->{'__disabled'}) {
+            if($add_as_class) {
+                $attr = add_classes($attr, 'disabled');
+            }
+            else {
+                $attr->{'disabled'} = 'disabled';
+            }
+        }
+        return $attr;
+    }
+
     sub contents {
         my $callback = shift;
         my $content = shift;
@@ -414,17 +470,13 @@ package Mojolicious::Plugin::BootstrapHelpers::Helpers {
 
     sub cleanup_attrs {
         my $hash = shift;
-        
-        map { delete $hash->{ $_ } } ('column_information',
-                                      'panel',
-                                      keys _sizes()->%*,
-                                      keys _button_contexts()->%*,
-                                      keys _panel_contexts()->%*,
-                                      keys _table_contexts()->%*,
-                                      keys _direction_contexts()->%*,
-                                      keys _menu_contexts()->%*);
-        # delete all attributes starting with __
-        map { delete $hash->{ $_ } } grep { substr $_, 0 => 2 eq '__' } keys $hash->%*;
+
+        #* delete all strappings (__*)
+        map { delete $hash->{ $_ } } grep { substr($_, 0, 2) eq '__' } keys $hash->%*;
+
+        #* delete all keys whose value is not a string
+        map { delete $hash->{ $_ } } grep { $_ ne 'data' && ref $hash->{ $_ } ne '' } keys $hash->%*;
+
         return $hash;
     }
 
@@ -453,10 +505,13 @@ package Mojolicious::Plugin::BootstrapHelpers::Helpers {
         return { map { ("__$_" => $_, $_ => $_) } qw/striped bordered hover condensed responsive/ };
     }
     sub _direction_contexts {
-        return { map { ("__$_" => $_, $_ => $_) } qw/right/ };
+        return { map { ("__$_" => $_, $_ => $_) } qw/right block/ };
     }
     sub _menu_contexts {
-        return { map { ("__$_" => $_, $_ => $_) } qw/caret divider/ };
+        return { map { ("__$_" => undef, $_ => undef) } qw/caret/ };
+    }
+    sub _misc_contexts {
+        return { map { ("__$_" => $_, $_ => $_) } qw/active disabled/ };
     }
 
     sub out {
